@@ -1,6 +1,6 @@
 /*
 
-    $Id: kmahjongg.cpp,v 1.62 2002/03/17 15:28:22 mlaurent Exp $
+    $Id: kmahjongg.cpp,v 1.62.2.2 2002/05/29 13:12:57 binner Exp $
 
     kmahjongg, the classic mahjongg game for KDE project
 
@@ -399,7 +399,9 @@ void KMahjonggWidget::setupMenuBar()
   game->insertItem( i18n("&Show Highscores..."), ID_GAME_SHOW_HISCORE );
   game->insertSeparator();
   game->insertItem( SmallIcon("player_pause"), i18n("&Pause"), ID_GAME_PAUSE );
+  game->setAccel(Key_P, ID_GAME_PAUSE);
   game->insertItem( SmallIcon("1rightarrow"), i18n("&Continue"), ID_GAME_CONTINUE );
+  game->setAccel(Key_C, ID_GAME_CONTINUE);
 
   QPopupMenu *help = helpMenu(QString(i18n("Mahjongg"))
            + " " + KMAHJONGG_VERSION
@@ -1511,7 +1513,7 @@ void BoardWidget::calculateNewGame( int gNumber)
     }
 
     if (gNumber == -1) {
-    	gameGenerationNum = 0;
+    	gameGenerationNum = kapp->random();
     } else {
 	gameGenerationNum = gNumber;
     }
@@ -1541,7 +1543,7 @@ bool BoardWidget::generateStartPosition2() {
 
 	memset(tilesLeft, 0, sizeof(tilesLeft));
 
-	// zero out all face values	
+	// zero out all face values
 	for (int z=0; z< BoardLayout::depth; z++) {
 	    for (int y=0; y<BoardLayout::height; y++) {
 		for (int x=0; x<BoardLayout::width; x++) {
