@@ -22,15 +22,15 @@
 #include <qtimer.h>
 
 #include <kdebug.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaccel.h>
 #include <klocale.h>
 #include <kconfig.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 
 #include "tron.h"
 
-#define FRAMESIZE 2
+#define TRON_FRAMESIZE 2
 
 /* *************************************************************** **
 **                    init-functions										 **
@@ -75,6 +75,8 @@ Tron::~Tron()
     }
   if(pixmap)
     delete pixmap;
+  delete timer;
+
 }
 
 void Tron::createNewPlayfield()
@@ -89,11 +91,11 @@ void Tron::createNewPlayfield()
 
   // field size
 
-  fieldWidth=(width()-2*FRAMESIZE)/rectSize;
-  fieldHeight=(height()-2*FRAMESIZE)/rectSize;
+  fieldWidth=(width()-2*TRON_FRAMESIZE)/rectSize;
+  fieldHeight=(height()-2*TRON_FRAMESIZE)/rectSize;
 
   // start positions
-  playfield=new QArray<int>[fieldWidth];
+  playfield=new QMemArray<int>[fieldWidth];
   for(int i=0;i<fieldWidth;i++)
     playfield[i].resize(fieldHeight);
 
@@ -279,11 +281,11 @@ void Tron::updatePixmap()
 
    p.setPen(NoPen);
    p.setBrush(light);
-      p.drawRect(width()-FRAMESIZE,0,FRAMESIZE,height());
-   p.drawRect(0,height()-FRAMESIZE,width(),FRAMESIZE);
+      p.drawRect(width()-TRON_FRAMESIZE,0,TRON_FRAMESIZE,height());
+   p.drawRect(0,height()-TRON_FRAMESIZE,width(),TRON_FRAMESIZE);
    p.setBrush(dark);
-   p.drawRect(0,0,width(),FRAMESIZE);
-   p.drawRect(0,0,FRAMESIZE,height());
+   p.drawRect(0,0,width(),TRON_FRAMESIZE);
+   p.drawRect(0,0,TRON_FRAMESIZE,height());
 
    p.end();
 }
@@ -513,6 +515,16 @@ bool Tron::winnerColor() const
    return changeWinnerColor;
 }
 
+void Tron::setOppositeDirCrashes(bool flag)
+{
+   crashOnOppositeDir=flag;
+}
+
+bool Tron::oppositeDirCrashes() const
+{
+   return crashOnOppositeDir;
+}
+
 void Tron::setComputerplayer(Player player, bool flag)
 {
   if(player==One)
@@ -590,8 +602,19 @@ void Tron::switchDir(int playerNr,Direction newDirection)
      return;
   }
 
-  players[playerNr].dir=newDirection;
+  if (oppositeDirCrashes()==false)
+  {
+    if (newDirection==::Up && players[playerNr].dir==::Down)
+      return;
+    if (newDirection==::Down && players[playerNr].dir==::Up)
+      return;
+    if (newDirection==::Left && players[playerNr].dir==::Right)
+      return;
+    if (newDirection==::Right && players[playerNr].dir==::Left)
+      return;
+  }
 
+  players[playerNr].dir=newDirection;
 }
 
 void Tron::updateDirections(int playerNr)
@@ -605,18 +628,18 @@ void Tron::updateDirections(int playerNr)
       switch(players[0].dir)
       {
          // unset drawing flags in the moving direction
-         case Up:
+         case ::Up:
          {
   	    playfield[x][y] &= (~TOP);
   	    break;
        	 }
-         case Down:
+         case ::Down:
             playfield[x][y] &= (~BOTTOM);
             break;
-         case Right:
+         case ::Right:
             playfield[x][y] &= (~RIGHT);
             break;
-         case Left:
+         case ::Left:
             playfield[x][y] &= (~LEFT);
             break;
       }
@@ -631,18 +654,18 @@ void Tron::updateDirections(int playerNr)
       switch(players[1].dir)
       {
           // unset drawing flags in the moving direction
-     	  case Up:
+     	  case ::Up:
      	  {
              playfield[x][y] &= (~TOP);
              break;
        	  }
-          case Down:
+          case ::Down:
              playfield[x][y] &= (~BOTTOM);
              break;
-          case Right:
+          case ::Right:
              playfield[x][y] &= (~RIGHT);
              break;
-          case Left:
+          case ::Left:
              playfield[x][y] &= (~LEFT);
              break;
       }
@@ -682,21 +705,21 @@ void Tron::paintEvent(QPaintEvent *e)
      	 {
             int x=players[i].xCoordinate*rectSize+(width()%rectSize)/2-w/2;
             int y=players[i].yCoordinate*rectSize+(height()%rectSize)/2;
-            if(players[i].dir==Right)
+            if(players[i].dir==::Right)
             {
                x+=rectSize;
                y+=rectSize/2;
             }
-            if(players[i].dir==Left)
+            if(players[i].dir==::Left)
             {
                y+=rectSize/2;
             }
-            if(players[i].dir==Down)
+            if(players[i].dir==::Down)
             {
                y+=rectSize;
                x+=rectSize/2;
             }
-            if(players[i].dir==Up)
+            if(players[i].dir==::Up)
             {
                x+=rectSize/2;
                y+=rectSize/3;
@@ -732,27 +755,27 @@ void Tron::keyPressEvent(QKeyEvent *e)
 
   if(!players[1].computer)
   {
-      if(key==accel->currentKey("Pl2Up"))
+      if(key==accel->shortcut("Pl2Up"))
 		{
-	  		switchDir(1,Up);
+	  		switchDir(1,::Up);
 	  		players[1].keyPressed=true;
 		}
-      else if(key==accel->currentKey("Pl2Left"))
+      else if(key==accel->shortcut("Pl2Left"))
 	   {
-	  		switchDir(1,Left);
+	  		switchDir(1,::Left);
 	  		players[1].keyPressed=true;
 		}
-      else if(key==accel->currentKey("Pl2Right"))
+      else if(key==accel->shortcut("Pl2Right"))
 		{
-	  		switchDir(1,Right);
+	  		switchDir(1,::Right);
 	  		players[1].keyPressed=true;
 		}
-      else if(key==accel->currentKey("Pl2Down"))
+      else if(key==accel->shortcut("Pl2Down"))
 		{
-	  		switchDir(1,Down);
+	  		switchDir(1,::Down);
 	  		players[1].keyPressed=true;
 		}
-      else if(key==accel->currentKey("Pl2Ac"))
+      else if(key==accel->shortcut("Pl2Ac"))
 		{
 		   if(!blockAccelerator)
 	  			players[1].accelerated=true;
@@ -762,28 +785,28 @@ void Tron::keyPressEvent(QKeyEvent *e)
 
   if(!players[0].computer)
   {
-      if(key==accel->currentKey("Pl1Left"))
+      if(key==accel->shortcut("Pl1Left"))
 		{
-	  		switchDir(0,Left);
+	  		switchDir(0,::Left);
 	  		players[0].keyPressed=true;
 		}
-      else if(key==accel->currentKey("Pl1Right"))
+      else if(key==accel->shortcut("Pl1Right"))
 		{
-	  		switchDir(0,Right);
+	  		switchDir(0,::Right);
 	  		players[0].keyPressed=true;
 		}
-      else if(key==accel->currentKey("Pl1Up"))
+      else if(key==accel->shortcut("Pl1Up"))
 		{
-	  		switchDir(0,Up);
+	  		switchDir(0,::Up);
 	  		players[0].keyPressed=true;
 		}
-      else if(key==accel->currentKey("Pl1Down"))
+      else if(key==accel->shortcut("Pl1Down"))
 		{
-	 		switchDir(0,Down);
+	 		switchDir(0,::Down);
 	  		players[0].keyPressed=true;
 		}
 
-      else if(key==accel->currentKey("Pl1Ac"))
+      else if(key==accel->shortcut("Pl1Ac"))
 		{
 		   if(!blockAccelerator)
 	  			players[0].accelerated=true;
@@ -819,28 +842,28 @@ void Tron::keyReleaseEvent(QKeyEvent * e)
 
   if(!players[1].computer)
   {
-      if(key==accel->currentKey("Pl2Ac"))
+      if(key==accel->shortcut("Pl2Ac"))
 	   {
 	      players[1].accelerated=false;
 	      return;
   		}
 
-		else if(key==accel->currentKey("Pl2Left"))
+		else if(key==accel->shortcut("Pl2Left"))
 		{
 	  		players[1].keyPressed=false;
 	  		return;
 		}
-      else if(key==accel->currentKey("Pl2Right"))
+      else if(key==accel->shortcut("Pl2Right"))
 		{
 	  		players[1].keyPressed=false;
 	  		return;
 		}
-      else if(key==accel->currentKey("Pl2Up"))
+      else if(key==accel->shortcut("Pl2Up"))
 		{
 	  		players[1].keyPressed=false;
 	  		return;
 		}
-      else if(key==accel->currentKey("Pl2Down"))
+      else if(key==accel->shortcut("Pl2Down"))
 		{
 		  players[1].keyPressed=false;
 		  return;
@@ -849,27 +872,27 @@ void Tron::keyReleaseEvent(QKeyEvent * e)
 
 	if(!players[0].computer)
    {
-   	if(key==accel->currentKey("Pl1Left"))
+   	if(key==accel->shortcut("Pl1Left"))
     	{
 	 		players[0].keyPressed=false;
 	 		return;
     	}
-      else if(key==accel->currentKey("Pl1Right"))
+      else if(key==accel->shortcut("Pl1Right"))
 		{
 	  		players[0].keyPressed=false;
 	  		return;
 		}
-      else if(key==accel->currentKey("Pl1Up"))
+      else if(key==accel->shortcut("Pl1Up"))
 		{
 	 		players[0].keyPressed=false;
 	  		return;
 		}
-     	else if(key==accel->currentKey("Pl1Down"))
+     	else if(key==accel->shortcut("Pl1Down"))
 		{
 	 		players[0].keyPressed=false;
 	 		return;
 		}
-      else if(key==accel->currentKey("Pl1Ac"))
+      else if(key==accel->shortcut("Pl1Ac"))
 		{
 	  		players[0].accelerated=false;
 	  		return;
@@ -934,7 +957,7 @@ void Tron::doMove()
 		   }
 	  		switch(players[i].dir)
 	    	{
-	    		case Up:
+	    		case ::Up:
 	      		if(crashed(i,0,-1))
 		 				players[i].alive=false;
 	      		else
@@ -943,7 +966,7 @@ void Tron::doMove()
 	      			newType|=(TOP | LEFT | RIGHT);
 	      		}
 	      		break;
-	    		case Down:
+	    		case ::Down:
 	    			if(crashed(i,0,1))
 	       			players[i].alive=false;
 	    			else
@@ -953,7 +976,7 @@ void Tron::doMove()
 	    			}
 
 	      		break;
-	    		case Left:
+	    		case ::Left:
 	       		if(crashed(i,-1,0))
 		 				players[i].alive=false;
 	       		else
@@ -962,7 +985,7 @@ void Tron::doMove()
 	       		   newType |= (LEFT | TOP | BOTTOM);
 	       		}
 	      		break;
-	    		case Right:
+	    		case ::Right:
 	      	if(crashed(i,1,0))
 					players[i].alive=false;
 	      	else
@@ -987,16 +1010,16 @@ void Tron::doMove()
 	  		int xInc=0,yInc=0;
 	  		switch(players[1].dir)
 	    	{
-	    		case Left:
+	    		case ::Left:
 	      		xInc = -1;
 	      		break;
-	    		case Right:
+	    		case ::Right:
 	      		xInc = 1;
 	      		break;
-	    		case Up:
+	    		case ::Up:
 	      		yInc = -1;
 	      		break;
-	    		case Down:
+	    		case ::Down:
 	      		yInc = 1;
 	      		break;
 	    	}
@@ -1058,7 +1081,7 @@ void Tron::doMove()
 
       switch(players[i].dir)
 		{
-			case Up:
+			case ::Up:
 	      	if(crashed(i,0,-1))
 					players[i].alive=false;
 	      	else
@@ -1067,7 +1090,7 @@ void Tron::doMove()
 	      	   newType |= (TOP | RIGHT | LEFT);
 	      	}
 	  			break;
-			case Down:
+			case ::Down:
 	      	if(crashed(i,0,1))
 					players[i].alive=false;
 	      	else
@@ -1076,7 +1099,7 @@ void Tron::doMove()
 	      	    newType |= (BOTTOM | RIGHT | LEFT);
 	      	}
 	  			break;
-			case Left:
+			case ::Left:
 	      	if(crashed(i,-1,0))
 					players[i].alive=false;
 	      	else
@@ -1085,7 +1108,7 @@ void Tron::doMove()
 	      	   newType |= (LEFT | TOP | BOTTOM);
 	      	}
 	  			break;
-			case Right:
+			case ::Right:
 	      	if(crashed(i,1,0))
 					players[i].alive=false;
 	      	else
@@ -1106,13 +1129,13 @@ void Tron::doMove()
       int xInc=0,yInc=0;
       switch(players[1].dir)
 		{
-			case Left:
+			case ::Left:
 	  			xInc = -1; break;
-			case Right:
+			case ::Right:
 	  			xInc = 1; break;
-			case Up:
+			case ::Up:
 	  			yInc = -1; break;
-			case Down:
+			case ::Down:
 	  			yInc = 1; break;
 		}
       if ((players[1].xCoordinate+xInc) == players[0].xCoordinate)
@@ -1178,7 +1201,7 @@ if(_skill != Easy)
 
   	switch (players[playerNr].dir)
    	{
-  			case Left:
+  			case ::Left:
     			//forward flags
     			flags[0] = -1;
     			flags[1] = 0;
@@ -1192,38 +1215,38 @@ if(_skill != Easy)
     			flags[5] = -1;
 
     			//turns to either side
-    			sides[0] = Down;
-    			sides[1] = Up;
+    			sides[0] = ::Down;
+    			sides[1] = ::Up;
     			break;
-  			case Right:
+  			case ::Right:
     			flags[0] = 1;
     			flags[1] = 0;
     			flags[2] = 0;
 			   flags[3] = -1;
     			flags[4] = 0;
     			flags[5] = 1;
-    			sides[0] = Up;
-    			sides[1] = Down;
+    			sides[0] = ::Up;
+    			sides[1] = ::Down;
     			break;
-  			case Up:
+  			case ::Up:
     			flags[0] = 0;
     			flags[1] = -1;
     			flags[2] = -1;
     			flags[3] = 0;
     			flags[4] = 1;
     			flags[5] = 0;
-    			sides[0] = Left;
-    			sides[1] = Right;
+    			sides[0] = ::Left;
+    			sides[1] = ::Right;
     			break;
-  			case Down:
+  			case ::Down:
     			flags[0] = 0;
     			flags[1] = 1;
     			flags[2] = 1;
     			flags[3] = 0;
     			flags[4] = -1;
     			flags[5] = 0;
-    			sides[0] = Right;
-    			sides[1] = Left;
+    			sides[0] = ::Right;
+    			sides[1] = ::Left;
     			break;
   		}
 
@@ -1276,52 +1299,52 @@ if(_skill != Easy)
 
   	switch(players[playerNr].dir)
   	{
-  	   case Up:
+  	   case ::Up:
   	      opForwardDis=vert_dis;
   	      opSideDis=-hor_dis;
-  	      if(players[opponent].dir==Down)
+  	      if(players[opponent].dir==::Down)
   	         opMovesOppositeDir=true;
-  	      else if(players[opponent].dir==Up)
+  	      else if(players[opponent].dir==::Up)
   	         opMovesSameDir=true;
-  	      else if(players[opponent].dir==Left)
+  	      else if(players[opponent].dir==::Left)
   	         opMovesLeft=true;
-  	      else if(players[opponent].dir==Right)
+  	      else if(players[opponent].dir==::Right)
   	         opMovesRight=true;
   	      break;
-  	   case Down:
+  	   case ::Down:
   	      opForwardDis=-vert_dis;
   	      opSideDis=hor_dis;
-  	      if(players[opponent].dir==Up)
+  	      if(players[opponent].dir==::Up)
   	         opMovesOppositeDir=true;
-  	      else if(players[opponent].dir==Down)
+  	      else if(players[opponent].dir==::Down)
   	         opMovesSameDir=true;
-  	      else if(players[opponent].dir==Left)
+  	      else if(players[opponent].dir==::Left)
   	         opMovesRight=true;
-  	      else if(players[opponent].dir==Right)
+  	      else if(players[opponent].dir==::Right)
   	         opMovesLeft=true;
   	      break;
-  	   case Left:
+  	   case ::Left:
   	      opForwardDis=hor_dis;
   	      opSideDis=vert_dis;
-  	      if(players[opponent].dir==Right)
+  	      if(players[opponent].dir==::Right)
   	         opMovesOppositeDir=true;
-  	      else if(players[opponent].dir==Left)
+  	      else if(players[opponent].dir==::Left)
   	         opMovesSameDir=true;
-  	      else if(players[opponent].dir==Down)
+  	      else if(players[opponent].dir==::Down)
   	         opMovesLeft=true;
-  	      else if(players[opponent].dir==Up)
+  	      else if(players[opponent].dir==::Up)
   	         opMovesRight=true;
   	      break;
-  	   case Right:
+  	   case ::Right:
   	      opForwardDis=-hor_dis;
   	      opSideDis=-vert_dis;
-  	      if(players[opponent].dir==Left)
+  	      if(players[opponent].dir==::Left)
   	         opMovesOppositeDir=true;
-  	      else if(players[opponent].dir==Right)
+  	      else if(players[opponent].dir==::Right)
   	         opMovesSameDir=true;
-  	      else if(players[opponent].dir==Up)
+  	      else if(players[opponent].dir==::Up)
   	         opMovesLeft=true;
-  	      else if(players[opponent].dir==Down)
+  	      else if(players[opponent].dir==::Down)
   	         opMovesRight=true;
   	      break;
   	}
@@ -1559,7 +1582,7 @@ else //_skill==Easy
   dis_forward = dis_left = dis_right = 1;
 
   switch (players[playerNr].dir) {
-  case Left:
+  case ::Left:
 
     //forward flags
     flags[0] = -1;
@@ -1574,38 +1597,38 @@ else //_skill==Easy
     flags[5] = -1;
 
     //turns to either side
-    sides[0] = Down;
-    sides[1] = Up;
+    sides[0] = ::Down;
+    sides[1] = ::Up;
     break;
-  case Right:
+  case ::Right:
     flags[0] = 1;
     flags[1] = 0;
     flags[2] = 0;
     flags[3] = -1;
     flags[4] = 0;
     flags[5] = 1;
-    sides[0] = Up;
-    sides[1] = Down;
+    sides[0] = ::Up;
+    sides[1] = ::Down;
     break;
-  case Up:
+  case ::Up:
     flags[0] = 0;
     flags[1] = -1;
     flags[2] = -1;
     flags[3] = 0;
     flags[4] = 1;
     flags[5] = 0;
-    sides[0] = Left;
-    sides[1] = Right;
+    sides[0] = ::Left;
+    sides[1] = ::Right;
     break;
-  case Down:
+  case ::Down:
     flags[0] = 0;
     flags[1] = 1;
     flags[2] = 1;
     flags[3] = 0;
     flags[4] = -1;
     flags[5] = 0;
-    sides[0] = Right;
-    sides[1] = Left;
+    sides[0] = ::Right;
+    sides[1] = ::Left;
     break;
   }
 
@@ -1678,22 +1701,22 @@ void Tron::changeDirection(int playerNr,int dis_right,int dis_left)
    Direction sides[2];
    switch (currentDir)
    {
-  		case Left:
+  		case ::Left:
     		//turns to either side
-    		sides[0] = Down;
-    		sides[1] = Up;
+    		sides[0] = ::Down;
+    		sides[1] = ::Up;
     		break;
-  		case Right:
-    		sides[0] = Up;
-    		sides[1] = Down;
+  		case ::Right:
+    		sides[0] = ::Up;
+    		sides[1] = ::Down;
     		break;
-  		case Up:
-    		sides[0] = Left;
-    		sides[1] = Right;
+  		case ::Up:
+    		sides[0] = ::Left;
+    		sides[1] = ::Right;
     		break;
-  		case Down:
-    		sides[0] = Right;
-    		sides[1] = Left;
+  		case ::Down:
+    		sides[0] = ::Right;
+    		sides[1] = ::Left;
     		break;
   	}
 
